************
zfit physics
************

.. image:: https://scikit-hep.org/assets/images/Scikit--HEP-Affiliated-blue.svg
   :target: https://scikit-hep.org

.. image:: https://img.shields.io/pypi/v/zfit_physics.svg
   :target: https://pypi.python.org/pypi/zfit_physics



|zfit_logo|


.. |zfit_logo| image:: docs/images/zfit-fin_400x168.png
   :target: https://github.com/zfit/zfit
   :alt: zfit logo

Documentation
 - `as part of zfit (zfit-physics part) <https://zfit.readthedocs.io/en/latest/user_api/zfit.pdf.html#physics-pdfs>`_
 - `zfit-physics (only) <https://zfit-physics.readthedocs.io/en/latest/>`_


Tools and models to extend `zfit <https://github.com/zfit/zfit>`_ with physics specific content.
Feel free to add your models, tools, etc. to this package.


The structure of this package is still in flow, so before opening any PR
you may want to open an issue to discuss how your proposed functionality will fit into `zfit-physics`.


What's new
=============

Check the `changelog <CHANGELOG.rst>`_ for recent changes.

Installing
==========


zfit-physics is available on pip and conda-forge (and LCG and spack).
Installation with pip has the newest stable version, and therefore recommended, while others may take weeks to months to update.
If possible, use a conda or virtual environment and do:


.. code-block:: console

    $ pip install zfit-physics

(add a -U to update to the newest version)

Installation with conda-forge is also possible:

.. code-block:: console

    $ conda install -c conda-forge zfit-physics


Contact
=======

You can contact us directly:
 - via e-mail: zfit@physik.uzh.ch
 - join our `Gitter channel <https://gitter.im/zfit/zfit>`_
 - open an `issue on GitHub <https://github.com/zfit/zfit-physics/issues/new/choose>`_ or `join the discussions <https://github.com/zfit/zfit-physics/discussions>`_ there
